
function ArchyArtifactListFrame_OnLoad(self)
	Archy:DebugPrint("Artifact List Frame Loaded");
	self:RegisterEvent("ARTIFACT_UPDATE");
	self:RegisterEvent("ARTIFACT_HISTORY_READY");
	self:RegisterEvent("ARTIFACT_COMPLETE");
	self:RegisterEvent("ARTIFACT_DIG_SITE_UPDATED");
	self:RegisterEvent("CURRENCY_DISPLAY_UPDATE");
--	self:RegisterEvent("SKILL_LINES_CHANGED");
	self:RegisterEvent("BAG_UPDATE");
end
			
function ArchyArtifactListFrame_OnEvent(self, event, ...)
	if event == "ARTIFACT_DIG_SITE_UPDATED" then
		Archy:UpdateArtifacts();
		ArchyArtifactListFrame_Update(self);
		
	elseif event == "BAG_UPDATE" then
		if Archy.RefreshOnNextBagUpdate then
			Archy:UpdateArtifacts();
			ArchyArtifactListFrame_Update(self);
			Archy.RefreshOnNextBagUpdate = false;
		end
		
		
	elseif event == "ARTIFACT_COMPLETE" then
		if Archy.SolvedArtifact then
			if not Archy.db.char.artifacts[Archy.SolvedArtifact.raceID] then
				Archy.db.char.artifacts[Archy.SolvedArtifact.raceID] = {};
			end
			if not Archy.db.char.artifacts[Archy.SolvedArtifact.raceID][Archy.SolvedArtifact.name] then
				Archy.db.char.artifacts[Archy.SolvedArtifact.raceID][Archy.SolvedArtifact.name] = { rarity = Archy.SolvedArtifact.rarity, count = 1 };
			else
				Archy.db.char.artifacts[Archy.SolvedArtifact.raceID][Archy.SolvedArtifact.name].count = Archy.db.char.artifacts[Archy.SolvedArtifact.raceID][Archy.SolvedArtifact.name].count + 1;
			end
			Archy:Print("Completed "..Archy.SolvedArtifact.raceName.." artifact: " .. Archy.SolvedArtifact.name .. " (x" .. Archy.db.char.artifacts[Archy.SolvedArtifact.raceID][Archy.SolvedArtifact.name].count .. " times)");
			Archy.SolvedArtifact = nil;
		end
		Archy:UpdateArtifacts();
		ArchyArtifactListFrame_Update(self);
	
	elseif event == "CURRENCY_DISPLAY_UPDATE" then
		Archy:UpdateArtifacts();
		ArchyArtifactListFrame_Update(self);
	end
end
			
function ArchyArtifactListFrame_OnShow(self)
	Archy:DebugPrint("ArchyArtifactListFrame_OnShow");
	Archy:UpdateArtifacts();
	ArchyArtifactListFrame_Update(self);
end
			
function ArchyArtifactListFrame_OnHide(self)
end


function ArchyArtifactListFrame_Update(self)
	if not Archy.RacesLoaded then
		return;
	end
	Archy:DebugPrint("Updating Artifact List");
	
	local currFrameNum = 1;
	local c = GetCurrentMapContinent();
	
	for i=1, Archy.MaxRaces do
		self["race"..i]:Hide();
		local showRace = true;
		if Archy.db.char.filterArtifactsByContinent then
			if Archy:IsValidContinent(c) then
				if not tContains(Archy.db.global.continentRaces[c], i) then
					showRace = false;
				end
			else
				showRace = false;
			end
		end
		if showRace and Archy.myArtifacts[i] then
			local artifact = Archy.myArtifacts[i];
			raceFrame = self["race"..currFrameNum];
			raceFrame.raceID = artifact.raceID;
			raceFrame.raceName = artifact.raceName;
			
			local base = artifact.progress;
			if artifact.progress >= artifact.totalCost then
				base = "|cFF00FF00" .. artifact.progress;
			else
				local adjust = Archy:CalculateSocketAdjust(artifact.numSockets, artifact.keystones);
				if artifact.progress + adjust >= artifact.totalCost then
					base = "|cFFFFFF00" .. artifact.progress;
				end
			end
			
			raceFrame.progress:SetText(base.."/"..artifact.totalCost);
			raceFrame.sockets.sockets = artifact.numSockets;
			raceFrame.sockets.keystones = artifact.keystones;
			raceFrame.sockets.keystoneName = artifact.keystoneName;
			
			if raceFrame.sockets.sockets > 0 or raceFrame.sockets.keystones > 0 then
				raceFrame.sockets.text:SetText(raceFrame.sockets.keystones .. "/" .. raceFrame.sockets.sockets);
				raceFrame.sockets:Show();
			else
				raceFrame.sockets:Hide();
			end
			
			if artifact.raceTexture and artifact.raceTexture ~= "" then
				raceFrame.solveButton:SetNormalTexture(artifact.raceTexture);
				raceFrame.solveButton:SetHighlightTexture(artifact.raceTexture);
			end
			local name = artifact.name;
			if name then
				if not artifact.pinged then
					if artifact.progress >= artifact.totalCost then
						artifact.pinged = true;
						if Archy.db.char.artifactReadyAnnounce then
							Archy:AnnounceArtifactReady(artifact.raceName, artifact.name, artifact.progress, artifact.totalCost)
						end
						if Archy.db.char.artifactReadyPing then
							Archy:DingDing();
						end
					end
				end
				if not artifact.pinged then
					local adjust = Archy:CalculateSocketAdjust(artifact.numSockets, artifact.keystones);
					if artifact.progress + adjust >= artifact.totalCost then
						if Archy.db.char.artifactReadyUsesKeystonesPing or Archy.db.char.artifactReadyUsesKeystonesAnnounce then
							artifact.pinged = true;
							if Archy.db.char.artifactReadyAnnounce and Archy.db.char.artifactReadyUsesKeystonesAnnounce then
								Archy:AnnounceArtifactReady(artifact.raceName, artifact.name, artifact.progress + adjust, artifact.totalCost)
							end
							if Archy.db.char.artifactReadyPing and Archy.db.char.artifactReadyUsesKeystonesPing then
								Archy:DingDing();
							end
						end
					end
				end
				

				if artifact.rarity ~= 0 and artifact.name then
					name = Archy.RareItemColorCode .. name .. "|r";
				else
					name = GRAY_FONT_COLOR_CODE .. name .. "|r";
				end
			end
			raceFrame.artifactButton.artifactName:SetText(name);
			raceFrame:Show();
			currFrameNum = currFrameNum + 1;
		end
	end
end

