local mapData = {};


function ArchyDigsiteListFrame_OnLoad(self)
	Archy:DebugPrint("Digsite List Frame Loaded");
	self:RegisterEvent("ARTIFACT_DIG_SITE_UPDATED");
	self:RegisterEvent("CHAT_MSG_LOOT");
	self:RegisterEvent("UNIT_SPELLCAST_SUCCEEDED");
	self:RegisterEvent("PLAYER_ENTERING_WORLD");
end

function ArchyDigsiteListFrame_OnEvent(self, event, ...)
	if event == "ARTIFACT_DIG_SITE_UPDATED" then
		Archy:UpdateDigsites();
		ArchyDigsiteListFrame_Update(self);
		
	elseif event == "CHAT_MSG_LOOT" then
		local msg = ...
		fragment_type, amount = strmatch(msg, "You receive currency: (.+) Archaeology Fragment x(%d+)")
		if fragment_type then
			local zone = GetZoneText()
			local subzone = GetSubZoneText()
			
			-- Add Digsite to DB if it hasn't been discovered yet
			if not Archy.db.global.digsites[Archy.LastDigsite] then
				Archy.db.global.digsites[Archy.LastDigsite] = { raceID = Archy.Races[fragment_type], nodes = {} };
			end

			local m, f, c, z, x, y = Archy:GetCurrentPlayerPosition();

			local hasNode = false;
			local radius = 0.25 * 0.25;			-- this will need to be tweaked later on
			for _,value in pairs(Archy.db.global.digsites[Archy.LastDigsite].nodes) do
				local mx = value.x*100 - x*100;
				local my = value.y*100 - y*100;
				if (mx*mx + my*my) <= radius then
					hasNode = true;
				end
			end

			if not hasNode then
				tinsert(Archy.db.global.digsites[Archy.LastDigsite].nodes, { m = m, f = f, x = x, y = y });
			end
			Archy:RefreshNodeMinimapIcons();
			
			-- Add race to the continent's race list if it doesn't exist
			if not tContains(Archy.db.global.continentRaces[GetCurrentMapContinent()], Archy.Races[fragment_type]) then
				tinsert(Archy.db.global.continentRaces[GetCurrentMapContinent()], Archy.Races[fragment_type]);
			end

			Archy.db.char.digsites[Archy.LastDigsite].looted = Archy.db.char.digsites[Archy.LastDigsite].looted + 1;
			Archy.db.char.digsites[Archy.LastDigsite].fragments = Archy.db.char.digsites[Archy.LastDigsite].fragments + amount;
			Archy.db.char.digsites[Archy.LastDigsite].counter = Archy.db.char.digsites[Archy.LastDigsite].counter + 1;
			if Archy.db.char.digsites[Archy.LastDigsite].counter == 3 then
				Archy.db.char.digsites[Archy.LastDigsite].counter = 0;
			end
			Archy:Refresh();

		else
			if string.find(msg, "You receive loot") then
				local _, itemLink, quantity = Archy:ParseLootMessage(msg);
				local _, _, Color, Ltype, itemID, Enchant, Gem1, Gem2, Gem3, Gem4, Suffix, Unique, LinkLvl, itemName = string.find(itemLink, "|?c?f?f?(%x*)|?H?([^:]*):?(%d+):?(%d*):?(%d*):?(%d*):?(%d*):?(%d*):?(%-?%d*):?(%-?%d*):?(%d*)|?h?%[?([^%[%]]*)%]?|?h?|?r?")
	
			  if Archy.KeystoneIDs[itemID] then

				Archy.db.char.digsites[Archy.LastDigsite].keystones = Archy.db.char.digsites[Archy.LastDigsite].keystones + quantity;

				Archy:RefreshArtifacts();
			  end
	      	end
		end

		
	elseif event == "UNIT_SPELLCAST_SUCCEEDED" then
		unit, spell, _, _ = ...
		if unit == "player" and spell == "Survey" then
			Archy.LastDigsite = Archy:NearestDigsiteName{anySite=1};
			local nearest = Archy:NearestDigsiteName();
			if nearest == Archy.LastDigsite then
				if Archy.db.char.useTomTom and not Archy.db.char.blacklist[Archy.LastDigsite] then
					Archy:DisableTomTom();
				end
			end
			
			if not Archy.db.char.digsites[Archy.LastDigsite] then
				Archy.db.char.digsites[Archy.LastDigsite] = { surveys = 0, fragments = 0, looted = 0, keystones = 0, counter = 0 };
			end
			Archy.db.char.digsites[Archy.LastDigsite].surveys = Archy.db.char.digsites[Archy.LastDigsite].surveys + 1;
			Archy:RefreshNodeMinimapIcons();
		end
			
	elseif event == "PLAYER_ENTERING_WORLD" then
		Archy:UpdateDigsites();
		if Archy:IsValidContinent(GetCurrentMapContinent()) then
			ArchyDigsiteListFrame_Update(self);
			if not Archy.db.char.hidden and not Archy.db.char.hiddenLists then
				ArchyDigsiteListFrame_Show(self);
				Archy.frames.artifacts:Show();
			end
			if Archy.db.char.hidden and Archy.db.char.useTomTom then
				Archy:DisableTomTom();
			end
		else
			ArchyDigsiteListFrame_Hide(self);
			Archy.frames.artifacts:Hide();
		end
	
	end
end
			
function ArchyDigsiteListFrame_OnShow(self)
	Archy:DebugPrint("ArchyDigsiteListFrame_OnShow");
	Archy:UpdateDigsites();
	ArchyDigsiteListFrame_Update(self);
end
			
function ArchyDigsiteListFrame_OnHide(self)
end

function ArchyDigsiteListFrame_Show(self)
	self:Show();
end

function ArchyDigsiteListFrame_Hide(self)
	self:Hide();
end


function ArchyDigsiteListFrame_Update(self)
	if not Archy.RacesLoaded or not Archy.hasArch then
		return;
	end
	local continentID = GetCurrentMapContinent();
	if not Archy.myDigsites[continentID] then
		return;
	end

	Archy:DebugPrint("Updating Digsite List for " .. continentID);
	for digsiteNum,digsite in ipairs(Archy.myDigsites[continentID]) do
		local name = digsite.name;
		if Archy.db.char.blacklist[name] then
			name = "|cFFFF0000" .. name;
		end
		Archy.db.char.digsites[digsite.name].counter = Archy.db.char.digsites[digsite.name].counter or 0;
		digsiteFrame = self["digsite"..digsiteNum];
		digsiteFrame.zone:SetText(digsite.zoneName);
		digsiteFrame.digsite.name:SetText(name);
		digsiteFrame.digCounter:SetText(Archy.db.char.digsites[digsite.name].counter .. "/3");
		digsiteFrame.raceID = digsite.raceID;
		digsiteFrame.raceName = digsite.raceName;
		digsiteFrame.icon:SetTexture(digsite.raceTexture);
		digsiteFrame.icon:SetSize(44,44);
		digsiteFrame:Show();
	end
end

